# Interaction

Connector page for the birdeye.so API.  
Each endpoint is mapped and callable via a dedicated method.  
Be sure to call an endpoint in line with the permissions of your API.

::: cyhole.birdeye.Birdeye
    options:
        filters:
            - "^_"
